"""
Glyph Markup Examples
=====================

Example markup snippets for testing and documentation.
"""

from .snippets import (
    BASIC_TEXT,
    BASIC_TWO_COLUMN,
    FORMATTED_HEADING,
    ACADEMIC_PAPER,
    BUSINESS_LETTER,
    RESUME,
)

__all__ = [
    "BASIC_TEXT",
    "BASIC_TWO_COLUMN",
    "FORMATTED_HEADING",
    "ACADEMIC_PAPER",
    "BUSINESS_LETTER",
    "RESUME",
]
